@@ -1,4 +1,3 @@
 import tmc.exercise_tests.basetest
-import tmc.exercise_tests.ant
-import tmc.exercise_tests.maven
 import tmc.exercise_tests.check
+import tmc.exercise_tests.java
